'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var version = "1.2.3";

var padZeros = function (input, maxLength) {
    if (maxLength === void 0) { maxLength = 0; }
    return ("0000" + input).slice(-maxLength);
};
var defaultConfig = {
    monthNames: [
        'January', 'February', 'March', 'April', 'May', 'June',
        'July', 'August', 'September', 'October', 'November', 'December'
    ],
    monthNamesShort: [
        'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
        'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'
    ]
};
var dateFormat = function (date, format, config) {
    if (format === void 0) { format = 'YYYY.MM.DD HH:mm:ss'; }
    if (config === void 0) { config = {}; }
    config = __assign({}, defaultConfig, config);
    return format
        // Normalize tokens
        .replace('YYYY', '%01%')
        .replace('YY', '%02%')
        .replace('MMMM', '%03%')
        .replace('MMM', '%04%')
        .replace('MM', '%05%')
        .replace('M', '%06%')
        .replace('DD', '%07%')
        .replace('D', '%08%')
        .replace('HH', '%09%')
        .replace('H', '%10%')
        .replace('hh', '%11%')
        .replace('h', '%12%')
        .replace('mm', '%13%')
        .replace('ss', '%14%')
        .replace('s', '%15%')
        .replace('A', '%16%')
        .replace('a', '%17%')
        // Insert values
        .replace('%01%', padZeros(date.getFullYear(), 4))
        .replace('%02%', padZeros(date.getFullYear() % 100, 2))
        .replace('%03%', "" + config.monthNames[date.getMonth()])
        .replace('%04%', "" + config.monthNamesShort[date.getMonth()])
        .replace('%05%', padZeros(date.getMonth() + 1, 2))
        .replace('%06%', "" + (date.getMonth() + 1))
        .replace('%07%', padZeros(date.getDate(), 2))
        .replace('%08%', "" + date.getDate())
        .replace('%09%', padZeros(date.getHours(), 2))
        .replace('%10%', "" + date.getHours())
        .replace('%11%', padZeros(date.getHours() % 12, 2))
        .replace('%12%', "" + date.getHours() % 12)
        .replace('%13%', padZeros(date.getMinutes(), 2))
        .replace('%14%', padZeros(date.getSeconds(), 2))
        .replace('%15%', "" + date.getSeconds())
        .replace('%16%', date.getHours() < 12 ? 'AM' : 'PM')
        .replace('%17%', date.getHours() < 12 ? 'am' : 'pm');
};

var main = {
    install: function (Vue, baseConfig) {
        Vue.filter('dateFormat', function (date, format, config) {
            if (config === void 0) { config = {}; }
            return dateFormat(date, format, __assign({}, config, baseConfig));
        });
    },
    version: version
};

exports.dateFormat = dateFormat;
exports.default = main;
